Welcome to WaveLink's Documentation!
========================================

WaveLink is a powerful and robust Lavalink wrapper for Discord.py.


Help and Support
------------------

- `GitHub <https://github.com/PythonistaGuild/Wavelink>`_
- `Discord <https://discord.gg/RAKc3HF>`_


.. toctree::
   :maxdepth: 1
   :caption: Getting Started:

   installing
   faq
   recipes

.. toctree::
   :maxdepth: 2
   :caption: API Reference:

   wavelink

.. toctree::
   :maxdepth: 2
   :caption: Extensions API's:

   exts/spotify


Indices and tables
==================

* :ref:`genindex`
* :ref:`search`
